@@ -2,7 +2,7 @@
 # License: GNU GPLv3
 # Copyright (c) 2017-2020 RedFantom
 
-package require Tk 8.6
+package require Tk 8.6-
 set png_theme_dir [file join [pwd] [file dirname [info script]]]
 
 array set png_themes {
@@ -12,7 +12,7 @@ array set png_themes {
   equilux 1.1
   scid 0.9.1
   ubuntu 1.0
-  yaru 0.1
+  yaru 1.2
 }
 
 foreach {theme version} [array get png_themes] {
